@@ -86,10 +86,10 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk
-import aws_cdk.aws_iam
-import aws_cdk.aws_sso
-import constructs
+import aws_cdk as _aws_cdk_ceddda9d
+import aws_cdk.aws_iam as _aws_cdk_aws_iam_ceddda9d
+import aws_cdk.aws_sso as _aws_cdk_aws_sso_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 @jsii.data_type(
@@ -100,7 +100,7 @@ import constructs
 class AssignmentAttributes:
     def __init__(self) -> None:
         '''Attributes for an assignment of which there are none.'''
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -127,7 +127,7 @@ class AssignmentOptions:
     def __init__(
         self,
         *,
-        principal: typing.Union["PrincipalProperty", typing.Dict[str, typing.Any]],
+        principal: typing.Union["PrincipalProperty", typing.Dict[builtins.str, typing.Any]],
         target_id: builtins.str,
         target_type: typing.Optional["TargetTypes"] = None,
     ) -> None:
@@ -140,18 +140,11 @@ class AssignmentOptions:
         if isinstance(principal, dict):
             principal = PrincipalProperty(**principal)
         if __debug__:
-            def stub(
-                *,
-                principal: typing.Union[PrincipalProperty, typing.Dict[str, typing.Any]],
-                target_id: builtins.str,
-                target_type: typing.Optional[TargetTypes] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__7ae439f39faaa114233bc0b1a16b1904736952c8fbf1932dc6475eed1f3d817a)
             check_type(argname="argument principal", value=principal, expected_type=type_hints["principal"])
             check_type(argname="argument target_id", value=target_id, expected_type=type_hints["target_id"])
             check_type(argname="argument target_type", value=target_type, expected_type=type_hints["target_type"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "principal": principal,
             "target_id": target_id,
         }
@@ -207,7 +200,7 @@ class AssignmentProps(AssignmentOptions):
     def __init__(
         self,
         *,
-        principal: typing.Union["PrincipalProperty", typing.Dict[str, typing.Any]],
+        principal: typing.Union["PrincipalProperty", typing.Dict[builtins.str, typing.Any]],
         target_id: builtins.str,
         target_type: typing.Optional["TargetTypes"] = None,
         permission_set: "IPermissionSet",
@@ -222,20 +215,12 @@ class AssignmentProps(AssignmentOptions):
         if isinstance(principal, dict):
             principal = PrincipalProperty(**principal)
         if __debug__:
-            def stub(
-                *,
-                principal: typing.Union[PrincipalProperty, typing.Dict[str, typing.Any]],
-                target_id: builtins.str,
-                target_type: typing.Optional[TargetTypes] = None,
-                permission_set: IPermissionSet,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__3677dd84d66e98c8bbf6b4b630ea271a32c589d1f12d4383871d2614207cad7b)
             check_type(argname="argument principal", value=principal, expected_type=type_hints["principal"])
             check_type(argname="argument target_id", value=target_id, expected_type=type_hints["target_id"])
             check_type(argname="argument target_type", value=target_type, expected_type=type_hints["target_type"])
             check_type(argname="argument permission_set", value=permission_set, expected_type=type_hints["permission_set"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "principal": principal,
             "target_id": target_id,
             "permission_set": permission_set,
@@ -288,12 +273,12 @@ class AssignmentProps(AssignmentOptions):
 @jsii.data_type(
     jsii_type="@renovosolutions/cdk-library-aws-sso.CustomerManagedPolicyReference",
     jsii_struct_bases=[
-        aws_cdk.aws_sso.CfnPermissionSet.CustomerManagedPolicyReferenceProperty
+        _aws_cdk_aws_sso_ceddda9d.CfnPermissionSet.CustomerManagedPolicyReferenceProperty
     ],
     name_mapping={"name": "name", "path": "path"},
 )
 class CustomerManagedPolicyReference(
-    aws_cdk.aws_sso.CfnPermissionSet.CustomerManagedPolicyReferenceProperty,
+    _aws_cdk_aws_sso_ceddda9d.CfnPermissionSet.CustomerManagedPolicyReferenceProperty,
 ):
     def __init__(
         self,
@@ -306,16 +291,10 @@ class CustomerManagedPolicyReference(
         :param path: ``CfnPermissionSet.CustomerManagedPolicyReferenceProperty.Path``.
         '''
         if __debug__:
-            def stub(
-                *,
-                name: builtins.str,
-                path: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__d76e58f544c6bf87eb4ed6045f0b6948c3216099d824187a7cc57942e89eb9fe)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument path", value=path, expected_type=type_hints["path"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "name": name,
         }
         if path is not None:
@@ -353,7 +332,7 @@ class CustomerManagedPolicyReference(
 
 
 @jsii.interface(jsii_type="@renovosolutions/cdk-library-aws-sso.IAssignment")
-class IAssignment(aws_cdk.IResource, typing_extensions.Protocol):
+class IAssignment(_aws_cdk_ceddda9d.IResource, typing_extensions.Protocol):
     '''The resource interface for an AWS SSO assignment.
 
     This interface has no attributes because the resulting resource has none.
@@ -363,7 +342,7 @@ class IAssignment(aws_cdk.IResource, typing_extensions.Protocol):
 
 
 class _IAssignmentProxy(
-    jsii.proxy_for(aws_cdk.IResource), # type: ignore[misc]
+    jsii.proxy_for(_aws_cdk_ceddda9d.IResource), # type: ignore[misc]
 ):
     '''The resource interface for an AWS SSO assignment.
 
@@ -378,7 +357,7 @@ typing.cast(typing.Any, IAssignment).__jsii_proxy_class__ = lambda : _IAssignmen
 
 
 @jsii.interface(jsii_type="@renovosolutions/cdk-library-aws-sso.IPermissionSet")
-class IPermissionSet(aws_cdk.IResource, typing_extensions.Protocol):
+class IPermissionSet(_aws_cdk_ceddda9d.IResource, typing_extensions.Protocol):
     '''The resource interface for an AWS SSO permission set.'''
 
     @builtins.property
@@ -404,7 +383,7 @@ class IPermissionSet(aws_cdk.IResource, typing_extensions.Protocol):
         self,
         id: builtins.str,
         *,
-        principal: typing.Union["PrincipalProperty", typing.Dict[str, typing.Any]],
+        principal: typing.Union["PrincipalProperty", typing.Dict[builtins.str, typing.Any]],
         target_id: builtins.str,
         target_type: typing.Optional["TargetTypes"] = None,
     ) -> "Assignment":
@@ -419,7 +398,7 @@ class IPermissionSet(aws_cdk.IResource, typing_extensions.Protocol):
 
 
 class _IPermissionSetProxy(
-    jsii.proxy_for(aws_cdk.IResource), # type: ignore[misc]
+    jsii.proxy_for(_aws_cdk_ceddda9d.IResource), # type: ignore[misc]
 ):
     '''The resource interface for an AWS SSO permission set.'''
 
@@ -448,7 +427,7 @@ class _IPermissionSetProxy(
         self,
         id: builtins.str,
         *,
-        principal: typing.Union["PrincipalProperty", typing.Dict[str, typing.Any]],
+        principal: typing.Union["PrincipalProperty", typing.Dict[builtins.str, typing.Any]],
         target_id: builtins.str,
         target_type: typing.Optional["TargetTypes"] = None,
     ) -> "Assignment":
@@ -460,15 +439,7 @@ class _IPermissionSetProxy(
         :param target_type: The entity type for which the assignment will be created. Default: TargetTypes.AWS_ACCOUNT
         '''
         if __debug__:
-            def stub(
-                id: builtins.str,
-                *,
-                principal: typing.Union[PrincipalProperty, typing.Dict[str, typing.Any]],
-                target_id: builtins.str,
-                target_type: typing.Optional[TargetTypes] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__63d08775b809b0e566cdb84b9c89847ac6e6605d16d5345595d249a8f665bbbe)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         assignment_options = AssignmentOptions(
             principal=principal, target_id=target_id, target_type=target_type
@@ -482,17 +453,21 @@ typing.cast(typing.Any, IPermissionSet).__jsii_proxy_class__ = lambda : _IPermis
 
 @jsii.data_type(
     jsii_type="@renovosolutions/cdk-library-aws-sso.PermissionBoundary",
-    jsii_struct_bases=[aws_cdk.aws_sso.CfnPermissionSet.PermissionsBoundaryProperty],
+    jsii_struct_bases=[
+        _aws_cdk_aws_sso_ceddda9d.CfnPermissionSet.PermissionsBoundaryProperty
+    ],
     name_mapping={
         "customer_managed_policy_reference": "customerManagedPolicyReference",
         "managed_policy_arn": "managedPolicyArn",
     },
 )
-class PermissionBoundary(aws_cdk.aws_sso.CfnPermissionSet.PermissionsBoundaryProperty):
+class PermissionBoundary(
+    _aws_cdk_aws_sso_ceddda9d.CfnPermissionSet.PermissionsBoundaryProperty,
+):
     def __init__(
         self,
         *,
-        customer_managed_policy_reference: typing.Optional[typing.Union[typing.Union[aws_cdk.aws_sso.CfnPermissionSet.CustomerManagedPolicyReferenceProperty, typing.Dict[str, typing.Any]], aws_cdk.IResolvable]] = None,
+        customer_managed_policy_reference: typing.Optional[typing.Union[typing.Union[_aws_cdk_aws_sso_ceddda9d.CfnPermissionSet.CustomerManagedPolicyReferenceProperty, typing.Dict[builtins.str, typing.Any]], _aws_cdk_ceddda9d.IResolvable]] = None,
         managed_policy_arn: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -500,16 +475,10 @@ class PermissionBoundary(aws_cdk.aws_sso.CfnPermissionSet.PermissionsBoundaryPro
         :param managed_policy_arn: ``CfnPermissionSet.PermissionsBoundaryProperty.ManagedPolicyArn``.
         '''
         if __debug__:
-            def stub(
-                *,
-                customer_managed_policy_reference: typing.Optional[typing.Union[typing.Union[aws_cdk.aws_sso.CfnPermissionSet.CustomerManagedPolicyReferenceProperty, typing.Dict[str, typing.Any]], aws_cdk.IResolvable]] = None,
-                managed_policy_arn: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__4b19ce1fb3e89b904939ce873e787c40e49146fc1e9defc30a9c9e3df0a22c16)
             check_type(argname="argument customer_managed_policy_reference", value=customer_managed_policy_reference, expected_type=type_hints["customer_managed_policy_reference"])
             check_type(argname="argument managed_policy_arn", value=managed_policy_arn, expected_type=type_hints["managed_policy_arn"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if customer_managed_policy_reference is not None:
             self._values["customer_managed_policy_reference"] = customer_managed_policy_reference
         if managed_policy_arn is not None:
@@ -518,13 +487,13 @@ class PermissionBoundary(aws_cdk.aws_sso.CfnPermissionSet.PermissionsBoundaryPro
     @builtins.property
     def customer_managed_policy_reference(
         self,
-    ) -> typing.Optional[typing.Union[aws_cdk.aws_sso.CfnPermissionSet.CustomerManagedPolicyReferenceProperty, aws_cdk.IResolvable]]:
+    ) -> typing.Optional[typing.Union[_aws_cdk_aws_sso_ceddda9d.CfnPermissionSet.CustomerManagedPolicyReferenceProperty, _aws_cdk_ceddda9d.IResolvable]]:
         '''``CfnPermissionSet.PermissionsBoundaryProperty.CustomerManagedPolicyReference``.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-sso-permissionset-permissionsboundary.html#cfn-sso-permissionset-permissionsboundary-customermanagedpolicyreference
         '''
         result = self._values.get("customer_managed_policy_reference")
-        return typing.cast(typing.Optional[typing.Union[aws_cdk.aws_sso.CfnPermissionSet.CustomerManagedPolicyReferenceProperty, aws_cdk.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[_aws_cdk_aws_sso_ceddda9d.CfnPermissionSet.CustomerManagedPolicyReferenceProperty, _aws_cdk_ceddda9d.IResolvable]], result)
 
     @builtins.property
     def managed_policy_arn(self) -> typing.Optional[builtins.str]:
@@ -549,24 +518,24 @@ class PermissionBoundary(aws_cdk.aws_sso.CfnPermissionSet.PermissionsBoundaryPro
 
 @jsii.implements(IPermissionSet)
 class PermissionSet(
-    aws_cdk.Resource,
+    _aws_cdk_ceddda9d.Resource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@renovosolutions/cdk-library-aws-sso.PermissionSet",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         name: builtins.str,
         sso_instance_arn: builtins.str,
-        aws_managed_policies: typing.Optional[typing.Sequence[aws_cdk.aws_iam.IManagedPolicy]] = None,
-        customer_managed_policy_references: typing.Optional[typing.Sequence[typing.Union[CustomerManagedPolicyReference, typing.Dict[str, typing.Any]]]] = None,
+        aws_managed_policies: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IManagedPolicy]] = None,
+        customer_managed_policy_references: typing.Optional[typing.Sequence[typing.Union[CustomerManagedPolicyReference, typing.Dict[builtins.str, typing.Any]]]] = None,
         description: typing.Optional[builtins.str] = None,
-        inline_policy: typing.Optional[aws_cdk.aws_iam.PolicyDocument] = None,
-        permissions_boundary: typing.Optional[typing.Union[PermissionBoundary, typing.Dict[str, typing.Any]]] = None,
+        inline_policy: typing.Optional[_aws_cdk_aws_iam_ceddda9d.PolicyDocument] = None,
+        permissions_boundary: typing.Optional[typing.Union[PermissionBoundary, typing.Dict[builtins.str, typing.Any]]] = None,
         relay_state_type: typing.Optional[builtins.str] = None,
-        session_duration: typing.Optional[aws_cdk.Duration] = None,
+        session_duration: typing.Optional[_aws_cdk_ceddda9d.Duration] = None,
     ) -> None:
         '''
         :param scope: -
@@ -582,22 +551,7 @@ class PermissionSet(
         :param session_duration: The length of time that the application user sessions are valid for.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                name: builtins.str,
-                sso_instance_arn: builtins.str,
-                aws_managed_policies: typing.Optional[typing.Sequence[aws_cdk.aws_iam.IManagedPolicy]] = None,
-                customer_managed_policy_references: typing.Optional[typing.Sequence[typing.Union[CustomerManagedPolicyReference, typing.Dict[str, typing.Any]]]] = None,
-                description: typing.Optional[builtins.str] = None,
-                inline_policy: typing.Optional[aws_cdk.aws_iam.PolicyDocument] = None,
-                permissions_boundary: typing.Optional[typing.Union[PermissionBoundary, typing.Dict[str, typing.Any]]] = None,
-                relay_state_type: typing.Optional[builtins.str] = None,
-                session_duration: typing.Optional[aws_cdk.Duration] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__9e1c8a3a6bbb48874bcc41baf50aebc1d5b3c196abd7611f29b515aa6e0683d9)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = PermissionSetProps(
@@ -618,7 +572,7 @@ class PermissionSet(
     @builtins.classmethod
     def from_permission_set_arn(
         cls,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         permission_set_arn: builtins.str,
     ) -> IPermissionSet:
@@ -629,13 +583,7 @@ class PermissionSet(
         :param permission_set_arn: -
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                permission_set_arn: builtins.str,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__1534cc83982ea2274a4ef806b10a9b22e16bd0a2ac53cb7e2d7d7e7e7f04522a)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument permission_set_arn", value=permission_set_arn, expected_type=type_hints["permission_set_arn"])
@@ -646,7 +594,7 @@ class PermissionSet(
         self,
         id: builtins.str,
         *,
-        principal: typing.Union["PrincipalProperty", typing.Dict[str, typing.Any]],
+        principal: typing.Union["PrincipalProperty", typing.Dict[builtins.str, typing.Any]],
         target_id: builtins.str,
         target_type: typing.Optional["TargetTypes"] = None,
     ) -> "Assignment":
@@ -658,15 +606,7 @@ class PermissionSet(
         :param target_type: The entity type for which the assignment will be created. Default: TargetTypes.AWS_ACCOUNT
         '''
         if __debug__:
-            def stub(
-                id: builtins.str,
-                *,
-                principal: typing.Union[PrincipalProperty, typing.Dict[str, typing.Any]],
-                target_id: builtins.str,
-                target_type: typing.Optional[TargetTypes] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__4cdc85e58620129e7f246a5cfde6e7c38745a843ac7234984317b311e146af34)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         assignment_options = AssignmentOptions(
             principal=principal, target_id=target_id, target_type=target_type
@@ -676,9 +616,9 @@ class PermissionSet(
 
     @builtins.property
     @jsii.member(jsii_name="cfnPermissionSet")
-    def cfn_permission_set(self) -> aws_cdk.aws_sso.CfnPermissionSet:
+    def cfn_permission_set(self) -> _aws_cdk_aws_sso_ceddda9d.CfnPermissionSet:
         '''The underlying CfnPermissionSet resource.'''
-        return typing.cast(aws_cdk.aws_sso.CfnPermissionSet, jsii.get(self, "cfnPermissionSet"))
+        return typing.cast(_aws_cdk_aws_sso_ceddda9d.CfnPermissionSet, jsii.get(self, "cfnPermissionSet"))
 
     @builtins.property
     @jsii.member(jsii_name="permissionSetArn")
@@ -714,16 +654,10 @@ class PermissionSetAttributes:
         :param sso_instance_arn: The SSO instance ARN of the permission set.
         '''
         if __debug__:
-            def stub(
-                *,
-                permission_set_arn: builtins.str,
-                sso_instance_arn: builtins.str,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__9f41d64f11736d4f2d569f1d67bc6cf42babd45687b8f3b4e4f35e92c7ff0fe3)
             check_type(argname="argument permission_set_arn", value=permission_set_arn, expected_type=type_hints["permission_set_arn"])
             check_type(argname="argument sso_instance_arn", value=sso_instance_arn, expected_type=type_hints["sso_instance_arn"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "permission_set_arn": permission_set_arn,
             "sso_instance_arn": sso_instance_arn,
         }
@@ -779,13 +713,13 @@ class PermissionSetProps:
         *,
         name: builtins.str,
         sso_instance_arn: builtins.str,
-        aws_managed_policies: typing.Optional[typing.Sequence[aws_cdk.aws_iam.IManagedPolicy]] = None,
-        customer_managed_policy_references: typing.Optional[typing.Sequence[typing.Union[CustomerManagedPolicyReference, typing.Dict[str, typing.Any]]]] = None,
+        aws_managed_policies: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IManagedPolicy]] = None,
+        customer_managed_policy_references: typing.Optional[typing.Sequence[typing.Union[CustomerManagedPolicyReference, typing.Dict[builtins.str, typing.Any]]]] = None,
         description: typing.Optional[builtins.str] = None,
-        inline_policy: typing.Optional[aws_cdk.aws_iam.PolicyDocument] = None,
-        permissions_boundary: typing.Optional[typing.Union[PermissionBoundary, typing.Dict[str, typing.Any]]] = None,
+        inline_policy: typing.Optional[_aws_cdk_aws_iam_ceddda9d.PolicyDocument] = None,
+        permissions_boundary: typing.Optional[typing.Union[PermissionBoundary, typing.Dict[builtins.str, typing.Any]]] = None,
         relay_state_type: typing.Optional[builtins.str] = None,
-        session_duration: typing.Optional[aws_cdk.Duration] = None,
+        session_duration: typing.Optional[_aws_cdk_ceddda9d.Duration] = None,
     ) -> None:
         '''The properties of a new permission set.
 
@@ -802,20 +736,7 @@ class PermissionSetProps:
         if isinstance(permissions_boundary, dict):
             permissions_boundary = PermissionBoundary(**permissions_boundary)
         if __debug__:
-            def stub(
-                *,
-                name: builtins.str,
-                sso_instance_arn: builtins.str,
-                aws_managed_policies: typing.Optional[typing.Sequence[aws_cdk.aws_iam.IManagedPolicy]] = None,
-                customer_managed_policy_references: typing.Optional[typing.Sequence[typing.Union[CustomerManagedPolicyReference, typing.Dict[str, typing.Any]]]] = None,
-                description: typing.Optional[builtins.str] = None,
-                inline_policy: typing.Optional[aws_cdk.aws_iam.PolicyDocument] = None,
-                permissions_boundary: typing.Optional[typing.Union[PermissionBoundary, typing.Dict[str, typing.Any]]] = None,
-                relay_state_type: typing.Optional[builtins.str] = None,
-                session_duration: typing.Optional[aws_cdk.Duration] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__81a500faaedc99c37669b04cc4cb3ded8f1161916dab975452e5e55c1cb669f0)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument sso_instance_arn", value=sso_instance_arn, expected_type=type_hints["sso_instance_arn"])
             check_type(argname="argument aws_managed_policies", value=aws_managed_policies, expected_type=type_hints["aws_managed_policies"])
@@ -825,7 +746,7 @@ class PermissionSetProps:
             check_type(argname="argument permissions_boundary", value=permissions_boundary, expected_type=type_hints["permissions_boundary"])
             check_type(argname="argument relay_state_type", value=relay_state_type, expected_type=type_hints["relay_state_type"])
             check_type(argname="argument session_duration", value=session_duration, expected_type=type_hints["session_duration"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "name": name,
             "sso_instance_arn": sso_instance_arn,
         }
@@ -861,13 +782,13 @@ class PermissionSetProps:
     @builtins.property
     def aws_managed_policies(
         self,
-    ) -> typing.Optional[typing.List[aws_cdk.aws_iam.IManagedPolicy]]:
+    ) -> typing.Optional[typing.List[_aws_cdk_aws_iam_ceddda9d.IManagedPolicy]]:
         '''The AWS managed policies to attach to the ``PermissionSet``.
 
         :default: - No AWS managed policies
         '''
         result = self._values.get("aws_managed_policies")
-        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_iam.IManagedPolicy]], result)
+        return typing.cast(typing.Optional[typing.List[_aws_cdk_aws_iam_ceddda9d.IManagedPolicy]], result)
 
     @builtins.property
     def customer_managed_policy_references(
@@ -893,13 +814,15 @@ class PermissionSetProps:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def inline_policy(self) -> typing.Optional[aws_cdk.aws_iam.PolicyDocument]:
+    def inline_policy(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_iam_ceddda9d.PolicyDocument]:
         '''The IAM inline policy that is attached to the permission set.
 
         :default: - No inline policy
         '''
         result = self._values.get("inline_policy")
-        return typing.cast(typing.Optional[aws_cdk.aws_iam.PolicyDocument], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_iam_ceddda9d.PolicyDocument], result)
 
     @builtins.property
     def permissions_boundary(self) -> typing.Optional[PermissionBoundary]:
@@ -944,10 +867,10 @@ class PermissionSetProps:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def session_duration(self) -> typing.Optional[aws_cdk.Duration]:
+    def session_duration(self) -> typing.Optional[_aws_cdk_ceddda9d.Duration]:
         '''The length of time that the application user sessions are valid for.'''
         result = self._values.get("session_duration")
-        return typing.cast(typing.Optional[aws_cdk.Duration], result)
+        return typing.cast(typing.Optional[_aws_cdk_ceddda9d.Duration], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -978,16 +901,10 @@ class PrincipalProperty:
         :param principal_type: The type of the principal.
         '''
         if __debug__:
-            def stub(
-                *,
-                principal_id: builtins.str,
-                principal_type: PrincipalTypes,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__ae5a8b88d8d2941e16b21bcde3962a352b3c0bcdac3ecd7b005ecb7859a601d5)
             check_type(argname="argument principal_id", value=principal_id, expected_type=type_hints["principal_id"])
             check_type(argname="argument principal_type", value=principal_type, expected_type=type_hints["principal_type"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "principal_id": principal_id,
             "principal_type": principal_type,
         }
@@ -1031,7 +948,7 @@ class TargetTypes(enum.Enum):
 
 @jsii.implements(IAssignment)
 class Assignment(
-    aws_cdk.Resource,
+    _aws_cdk_ceddda9d.Resource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@renovosolutions/cdk-library-aws-sso.Assignment",
 ):
@@ -1042,11 +959,11 @@ class Assignment(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         permission_set: IPermissionSet,
-        principal: typing.Union[PrincipalProperty, typing.Dict[str, typing.Any]],
+        principal: typing.Union[PrincipalProperty, typing.Dict[builtins.str, typing.Any]],
         target_id: builtins.str,
         target_type: typing.Optional[TargetTypes] = None,
     ) -> None:
@@ -1059,17 +976,7 @@ class Assignment(
         :param target_type: The entity type for which the assignment will be created. Default: TargetTypes.AWS_ACCOUNT
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                permission_set: IPermissionSet,
-                principal: typing.Union[PrincipalProperty, typing.Dict[str, typing.Any]],
-                target_id: builtins.str,
-                target_type: typing.Optional[TargetTypes] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__5eca7b2cf47acacd3579840411d5aee15f9a9bf2f86aefe69c49c627750efbf7)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = AssignmentProps(
@@ -1100,3 +1007,126 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__7ae439f39faaa114233bc0b1a16b1904736952c8fbf1932dc6475eed1f3d817a(
+    *,
+    principal: typing.Union[PrincipalProperty, typing.Dict[builtins.str, typing.Any]],
+    target_id: builtins.str,
+    target_type: typing.Optional[TargetTypes] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3677dd84d66e98c8bbf6b4b630ea271a32c589d1f12d4383871d2614207cad7b(
+    *,
+    principal: typing.Union[PrincipalProperty, typing.Dict[builtins.str, typing.Any]],
+    target_id: builtins.str,
+    target_type: typing.Optional[TargetTypes] = None,
+    permission_set: IPermissionSet,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d76e58f544c6bf87eb4ed6045f0b6948c3216099d824187a7cc57942e89eb9fe(
+    *,
+    name: builtins.str,
+    path: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__63d08775b809b0e566cdb84b9c89847ac6e6605d16d5345595d249a8f665bbbe(
+    id: builtins.str,
+    *,
+    principal: typing.Union[PrincipalProperty, typing.Dict[builtins.str, typing.Any]],
+    target_id: builtins.str,
+    target_type: typing.Optional[TargetTypes] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4b19ce1fb3e89b904939ce873e787c40e49146fc1e9defc30a9c9e3df0a22c16(
+    *,
+    customer_managed_policy_reference: typing.Optional[typing.Union[typing.Union[_aws_cdk_aws_sso_ceddda9d.CfnPermissionSet.CustomerManagedPolicyReferenceProperty, typing.Dict[builtins.str, typing.Any]], _aws_cdk_ceddda9d.IResolvable]] = None,
+    managed_policy_arn: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9e1c8a3a6bbb48874bcc41baf50aebc1d5b3c196abd7611f29b515aa6e0683d9(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    name: builtins.str,
+    sso_instance_arn: builtins.str,
+    aws_managed_policies: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IManagedPolicy]] = None,
+    customer_managed_policy_references: typing.Optional[typing.Sequence[typing.Union[CustomerManagedPolicyReference, typing.Dict[builtins.str, typing.Any]]]] = None,
+    description: typing.Optional[builtins.str] = None,
+    inline_policy: typing.Optional[_aws_cdk_aws_iam_ceddda9d.PolicyDocument] = None,
+    permissions_boundary: typing.Optional[typing.Union[PermissionBoundary, typing.Dict[builtins.str, typing.Any]]] = None,
+    relay_state_type: typing.Optional[builtins.str] = None,
+    session_duration: typing.Optional[_aws_cdk_ceddda9d.Duration] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1534cc83982ea2274a4ef806b10a9b22e16bd0a2ac53cb7e2d7d7e7e7f04522a(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    permission_set_arn: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4cdc85e58620129e7f246a5cfde6e7c38745a843ac7234984317b311e146af34(
+    id: builtins.str,
+    *,
+    principal: typing.Union[PrincipalProperty, typing.Dict[builtins.str, typing.Any]],
+    target_id: builtins.str,
+    target_type: typing.Optional[TargetTypes] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9f41d64f11736d4f2d569f1d67bc6cf42babd45687b8f3b4e4f35e92c7ff0fe3(
+    *,
+    permission_set_arn: builtins.str,
+    sso_instance_arn: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__81a500faaedc99c37669b04cc4cb3ded8f1161916dab975452e5e55c1cb669f0(
+    *,
+    name: builtins.str,
+    sso_instance_arn: builtins.str,
+    aws_managed_policies: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IManagedPolicy]] = None,
+    customer_managed_policy_references: typing.Optional[typing.Sequence[typing.Union[CustomerManagedPolicyReference, typing.Dict[builtins.str, typing.Any]]]] = None,
+    description: typing.Optional[builtins.str] = None,
+    inline_policy: typing.Optional[_aws_cdk_aws_iam_ceddda9d.PolicyDocument] = None,
+    permissions_boundary: typing.Optional[typing.Union[PermissionBoundary, typing.Dict[builtins.str, typing.Any]]] = None,
+    relay_state_type: typing.Optional[builtins.str] = None,
+    session_duration: typing.Optional[_aws_cdk_ceddda9d.Duration] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ae5a8b88d8d2941e16b21bcde3962a352b3c0bcdac3ecd7b005ecb7859a601d5(
+    *,
+    principal_id: builtins.str,
+    principal_type: PrincipalTypes,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5eca7b2cf47acacd3579840411d5aee15f9a9bf2f86aefe69c49c627750efbf7(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    permission_set: IPermissionSet,
+    principal: typing.Union[PrincipalProperty, typing.Dict[builtins.str, typing.Any]],
+    target_id: builtins.str,
+    target_type: typing.Optional[TargetTypes] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
